CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
100 lines
2.8 KiB
C++
100 lines
2.8 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include "streamCommon.hh"
|
|
#include <utils.hh>
|
|
/**
|
|
* @brief Check that querying a stream with no work returns hipSuccess
|
|
*
|
|
**/
|
|
HIP_TEST_CASE(Unit_hipStreamQuery_WithNoWork) {
|
|
hipStream_t stream{nullptr};
|
|
|
|
SECTION("Null Stream") { HIP_CHECK(hipStreamQuery(stream)); }
|
|
|
|
SECTION("Created Stream") {
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
HIP_CHECK(hipStreamQuery(stream));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
}
|
|
|
|
/**
|
|
* @brief Check that querying a stream with finished work returns hipSuccess
|
|
*
|
|
**/
|
|
HIP_TEST_CASE(Unit_hipStreamQuery_WithFinishedWork) {
|
|
hipStream_t stream{nullptr};
|
|
|
|
SECTION("Null Stream") {
|
|
hip::stream::empty_kernel<<<dim3(1), dim3(1), 0, stream>>>();
|
|
HIP_CHECK(hipStreamSynchronize(stream));
|
|
|
|
HIP_CHECK(hipStreamQuery(stream));
|
|
}
|
|
|
|
SECTION("Created Stream") {
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
hip::stream::empty_kernel<<<dim3(1), dim3(1), 0, stream>>>();
|
|
HIP_CHECK(hipStreamSynchronize(stream));
|
|
|
|
HIP_CHECK(hipStreamQuery(stream));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
}
|
|
|
|
#if HT_AMD /* Disabled because frequency based wait is timing out on nvidia platforms */
|
|
|
|
/**
|
|
* @brief Check that submitting work to a stream sets the status of the nullStream to
|
|
* hipErrorNotReady
|
|
*
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipStreamQuery_SubmitWorkOnStreamAndQueryNullStream) {
|
|
{
|
|
hipStream_t stream;
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
|
|
HIP_CHECK(hipStreamQuery(hip::nullStream));
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 500), stream);
|
|
HIP_CHECK_ERROR(hipStreamQuery(hip::nullStream), hipErrorNotReady);
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
}
|
|
|
|
/**
|
|
* @brief Check that submitting work to the nullStream properly sets its status as
|
|
* hipErrorNotReady.
|
|
*
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipStreamQuery_NullStreamQuery) {
|
|
HIP_CHECK(hipStreamQuery(hip::nullStream));
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 500), hip::nullStream);
|
|
HIP_CHECK_ERROR(hipStreamQuery(hip::nullStream), hipErrorNotReady);
|
|
|
|
HIP_CHECK(hipStreamSynchronize(hip::nullStream));
|
|
}
|
|
|
|
/**
|
|
* @brief Check that querying a stream with pending work returns hipErrorNotReady
|
|
*
|
|
**/
|
|
HIP_TEST_CASE(Unit_hipStreamQuery_WithPendingWork) {
|
|
hipStream_t waitingStream{nullptr};
|
|
HIP_CHECK(hipStreamCreate(&waitingStream));
|
|
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 500), waitingStream);
|
|
HIP_CHECK_ERROR(hipStreamQuery(waitingStream), hipErrorNotReady);
|
|
HIP_CHECK(hipStreamSynchronize(waitingStream));
|
|
HIP_CHECK(hipStreamQuery(waitingStream));
|
|
|
|
HIP_CHECK(hipStreamDestroy(waitingStream));
|
|
}
|
|
#endif
|